diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/ICommonClientService.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/ICommonClientService.java
index 41a9e1661db312c5eb4ec752593e021e83435d1b..ed9a85ce0dc622b211b1e44765079decca9d8084 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/ICommonClientService.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/ICommonClientService.java
@@ -60,6 +60,7 @@ import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DataSetType;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DataStoreServiceKind;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DataType;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DatastoreServiceDescription;
+import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DeletionType;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DetailedSearchCriteria;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DynamicPropertyEvaluationInfo;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.EntityKind;
@@ -644,17 +645,19 @@ public interface ICommonClientService extends IClientService
     public void deleteDataSet(String singleData, String reason) throws UserFailureException;
 
     /**
-     * Deletes the specified samples. NOTE: this is a stale version used only for samples with
-     * abundance.
+     * Deletes/Invalidates the specified samples. NOTE: this is a stale version used only for
+     * samples with abundance.
      */
-    public void deleteSamples(List<TechId> sampleIds, String reason) throws UserFailureException;
+    public void deleteSamples(List<TechId> sampleIds, String reason, DeletionType deletionType)
+            throws UserFailureException;
 
-    /** Deletes the specified samples. */
+    /** Deletes/Invalidates the specified samples. */
     public void deleteSamples(DisplayedOrSelectedIdHolderCriteria<? extends IIdHolder> criteria,
-            String reason) throws UserFailureException;
+            String reason, DeletionType deletionType) throws UserFailureException;
 
-    /** Deletes the specified sample. */
-    public void deleteSample(TechId sampleId, String reason) throws UserFailureException;
+    /** Deletes/Invalidates the specified sample. */
+    public void deleteSample(TechId sampleId, String reason, DeletionType deletionType)
+            throws UserFailureException;
 
     /** Deletes the specified experiments. */
     public void deleteExperiments(
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/ICommonClientServiceAsync.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/ICommonClientServiceAsync.java
index 80be7c17bea687292a0da58ee5bfe49c73229eae..72fb1f7f88d742b0a7616eb6fd789f3946aefd95 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/ICommonClientServiceAsync.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/ICommonClientServiceAsync.java
@@ -62,6 +62,7 @@ import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DataSetType;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DataStoreServiceKind;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DataType;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DatastoreServiceDescription;
+import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DeletionType;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DetailedSearchCriteria;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DynamicPropertyEvaluationInfo;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.EntityKind;
@@ -548,42 +549,46 @@ public interface ICommonClientServiceAsync extends IClientServiceAsync
     /** @see ICommonClientService#deleteDataSet(String, String) */
     public void deleteDataSet(String singleData, String reason, AsyncCallback<Void> asyncCallback);
 
-    /** @see ICommonClientService#deleteSamples(List, String) */
-    public void deleteSamples(List<TechId> sampleIds, String value,
+    /** @see ICommonClientService#deleteSamples(List, String, DeletionType) */
+    public void deleteSamples(List<TechId> sampleIds, String reason, DeletionType type,
             AsyncCallback<Void> asyncCallback);
 
-    /** @see ICommonClientService#deleteSamples(DisplayedOrSelectedIdHolderCriteria, String) */
+    /**
+     * @see ICommonClientService#deleteSamples(DisplayedOrSelectedIdHolderCriteria, String,
+     *      DeletionType)
+     */
     public void deleteSamples(DisplayedOrSelectedIdHolderCriteria<? extends IIdHolder> criteria,
-            String value, AsyncCallback<Void> asyncCallback);
+            String reason, DeletionType type, AsyncCallback<Void> asyncCallback);
 
-    /** @see ICommonClientService#deleteSample(TechId, String) */
-    public void deleteSample(TechId sampleIs, String value, AsyncCallback<Void> asyncCallback);
+    /** @see ICommonClientService#deleteSample(TechId, String, DeletionType) */
+    public void deleteSample(TechId sampleIs, String reason, DeletionType type,
+            AsyncCallback<Void> asyncCallback);
 
     /** @see ICommonClientService#deleteExperiments(DisplayedOrSelectedIdHolderCriteria, String) */
     public void deleteExperiments(
             DisplayedOrSelectedIdHolderCriteria<TableModelRowWithObject<Experiment>> criteria,
-            String value, AsyncCallback<Void> asyncCallback);
+            String reason, AsyncCallback<Void> asyncCallback);
 
     /** @see ICommonClientService#deleteExperiment(TechId, String) */
-    public void deleteExperiment(TechId experimentId, String value,
+    public void deleteExperiment(TechId experimentId, String reason,
             AsyncCallback<Void> asyncCallback);
 
     /** @see ICommonClientService#deleteProjects(List, String) */
-    public void deleteProjects(List<TechId> projectIds, String value,
+    public void deleteProjects(List<TechId> projectIds, String reason,
             AsyncCallback<Void> asyncCallback);
 
     /** @see ICommonClientService#deleteGroups(List, String) */
-    public void deleteGroups(List<TechId> groupIds, String value, AsyncCallback<Void> asyncCallback);
+    public void deleteGroups(List<TechId> groupIds, String reason, AsyncCallback<Void> asyncCallback);
 
     /** @see ICommonClientService#deleteScripts(List) */
     public void deleteScripts(List<TechId> scriptIds, AsyncCallback<Void> asyncCallback);
 
     /** @see ICommonClientService#deleteVocabularies(List, String) */
-    public void deleteVocabularies(List<TechId> vocabularyIds, String value,
+    public void deleteVocabularies(List<TechId> vocabularyIds, String reason,
             AsyncCallback<Void> asyncCallback);
 
     /** @see ICommonClientService#deletePropertyTypes(List, String) */
-    public void deletePropertyTypes(List<TechId> propertyTypeIds, String value,
+    public void deletePropertyTypes(List<TechId> propertyTypeIds, String reason,
             AsyncCallback<Void> asyncCallback);
 
     /** @see ICommonClientService#deleteAttachments(TechId, AttachmentHolderKind, List, String) */
@@ -898,7 +903,7 @@ public interface ICommonClientServiceAsync extends IClientServiceAsync
 
     /** @see ICommonClientService#deleteMaterials(DisplayedOrSelectedIdHolderCriteria, String) */
     public void deleteMaterials(DisplayedOrSelectedIdHolderCriteria<Material> uploadCriteria,
-            String value, AsyncCallback<Void> callback);
+            String reason, AsyncCallback<Void> callback);
 
     /**
      * @see ICommonClientService#lockDatasets(DisplayedOrSelectedDatasetCriteria)
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/Dict.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/Dict.java
index 66c66880a48286e3473d40d63519778cd2c02af3..840b00f5415b7122af6f1ed181aee852db2d205d 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/Dict.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/Dict.java
@@ -476,6 +476,29 @@ public abstract class Dict
 
     // -------- generic plugin dictionary -------------------
 
+    //
+    // Deletion
+    //
+
+    public static final String INVALIDATE = "invalidate";
+
+    public static final String INVALIDATION = "invalidation";
+
+    public static final String INVALIDATION_TEMPLATE = "invalidation_template";
+
+    public static final String PERMANENT = "permanent";
+
+    public static final String DELETE_CONFIRMATION_TITLE = "delete_confirmation_title";
+
+    public static final String DELETE_CONFIRMATION_MESSAGE = "delete_confirmation_message";
+
+    public static final String DELETE_CONFIRMATION_MESSAGE_WITH_REASON =
+            "delete_confirmation_message_with_reason";
+
+    public static final String DELETE_PROGRESS_MESSAGE = "delete_progress_message";
+
+    public static final String INVALIDATE_PROGRESS_MESSAGE = "invalidate_progress_message";
+
     //
     // Sample Viewer
     //
@@ -492,10 +515,6 @@ public abstract class Dict
 
     public static final String EXTERNAL_DATA_HEADING = "external_data_heading";
 
-    public static final String INVALIDATION = "invalidation";
-
-    public static final String INVALIDATION_TEMPLATE = "invalidation_template";
-
     public static final String SHOW_ONLY_DIRECTLY_CONNECTED = "show_only_directly_connected";
 
     //
@@ -950,23 +969,6 @@ public abstract class Dict
 
     public static final String BUTTON_DELETE = "button_delete";
 
-    public static final String DELETE_CONFIRMATION_TITLE = "delete_confirmation_title";
-
-    public static final String DELETE_CONFIRMATION_MESSAGE = "delete_confirmation_message";
-
-    public static final String DELETE_CONFIRMATION_MESSAGE_WITH_REASON =
-            "delete_confirmation_message_with_reason";
-
-    public static final String DELETE_PROGRESS_MESSAGE = "delete_progress_message";
-
-    public static final String DELETE_CONFIRMATION_WARNING = "delete_confirmation_warning";
-
-    public static final String DELETE_CONFIRMATION_WARNING_PART_FOR_EXPERIMENT =
-            "delete_confirmation_warning_part_for_experiment";
-
-    public static final String DELETE_CONFIRMATION_WARNING_PART_FOR_SAMPLE =
-            "delete_confirmation_warning_part_for_sample";
-
     public static final String BUTTON_CONFIGURE = "button_configure";
 
     public static final String BUTTON_FILTERS = "button_filters";
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/sample/SampleListDeletionConfirmationDialog.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/sample/SampleListDeletionConfirmationDialog.java
index a47523b484e1bd97f7d7c165d52dacd7cfeb5fc1..6cf83bc5a7e1be4d12f5f917ba134b3880add0e4 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/sample/SampleListDeletionConfirmationDialog.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/sample/SampleListDeletionConfirmationDialog.java
@@ -32,6 +32,7 @@ import ch.systemsx.cisd.openbis.generic.client.web.client.application.util.Widge
 import ch.systemsx.cisd.openbis.generic.client.web.client.dto.DisplayedOrSelectedIdHolderCriteria;
 import ch.systemsx.cisd.openbis.generic.shared.basic.IIdHolder;
 import ch.systemsx.cisd.openbis.generic.shared.basic.TechId;
+import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DeletionType;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.EntityKind;
 
 public final class SampleListDeletionConfirmationDialog<T extends IIdHolder> extends
@@ -68,16 +69,18 @@ public final class SampleListDeletionConfirmationDialog<T extends IIdHolder> ext
     @Override
     protected void executeDeletion(AsyncCallback<Void> deletionCallback)
     {
+        DeletionType deletionType =
+                isPermanentDeletion() ? DeletionType.PERMANENT : DeletionType.INVALIDATION;
         if (selectedAndDisplayedItemsOrNull != null)
         {
             final DisplayedOrSelectedIdHolderCriteria<T> uploadCriteria =
                     selectedAndDisplayedItemsOrNull.createCriteria(isOnlySelected());
             viewContext.getCommonService().deleteSamples(uploadCriteria, reason.getValue(),
-                    deletionCallback);
+                    deletionType, deletionCallback);
         } else
         {
             viewContext.getCommonService().deleteSample(TechId.create(singleDataOrNull),
-                    reason.getValue(), deletionCallback);
+                    reason.getValue(), deletionType, deletionCallback);
         }
     }
 
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/widget/AbstractDataListDeletionConfirmationDialog.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/widget/AbstractDataListDeletionConfirmationDialog.java
index 512e1166d045206c87cf2f4969d56c5cb6b770da..a81e00fa1f4bae9bf5ff6135e4af45806ba90c2e 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/widget/AbstractDataListDeletionConfirmationDialog.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/client/application/ui/widget/AbstractDataListDeletionConfirmationDialog.java
@@ -18,6 +18,9 @@ package ch.systemsx.cisd.openbis.generic.client.web.client.application.ui.widget
 
 import java.util.List;
 
+import com.extjs.gxt.ui.client.event.Events;
+import com.extjs.gxt.ui.client.event.FieldEvent;
+import com.extjs.gxt.ui.client.event.Listener;
 import com.extjs.gxt.ui.client.widget.form.Radio;
 import com.extjs.gxt.ui.client.widget.form.RadioGroup;
 import com.google.gwt.user.client.rpc.AsyncCallback;
@@ -25,6 +28,7 @@ import com.google.gwt.user.client.rpc.AsyncCallback;
 import ch.systemsx.cisd.openbis.generic.client.web.client.application.AbstractAsyncCallback;
 import ch.systemsx.cisd.openbis.generic.client.web.client.application.AsyncCallbackWithProgressBar;
 import ch.systemsx.cisd.openbis.generic.client.web.client.application.Dict;
+import ch.systemsx.cisd.openbis.generic.client.web.client.application.ui.field.CheckBoxField;
 import ch.systemsx.cisd.openbis.generic.client.web.client.application.ui.field.ReasonField;
 import ch.systemsx.cisd.openbis.generic.client.web.client.application.util.IMessageProvider;
 import ch.systemsx.cisd.openbis.generic.client.web.client.application.util.WidgetUtils;
@@ -46,27 +50,44 @@ public abstract class AbstractDataListDeletionConfirmationDialog<T> extends
 
     private static final String SELECTED = " selected ";
 
+    private static final String TEMPORARILY = "temporarily";
+
+    private static final String PERMANENTLY_EMPHASIZED = "<b>permanently</b>";
+
     private final AbstractAsyncCallback<Void> callback;
 
     private final boolean withRadio;
 
+    private final boolean withInvalidateOption;
+
     protected Radio onlySelectedRadioOrNull;
 
+    protected CheckBoxField permanentCheckBoxOrNull;
+
     protected ReasonField reason;
 
     public AbstractDataListDeletionConfirmationDialog(IMessageProvider messageProvider,
-            List<T> data, AbstractAsyncCallback<Void> callback, boolean withRadio)
+            List<T> data, AbstractAsyncCallback<Void> callback, boolean withRadio,
+            boolean withInvalidateOption)
     {
         super(messageProvider, data, messageProvider.getMessage(Dict.DELETE_CONFIRMATION_TITLE));
         this.callback = callback;
         this.withRadio = withRadio;
+        this.withInvalidateOption = withInvalidateOption;
+    }
+
+    // maybe with radio & temporarily
+    public AbstractDataListDeletionConfirmationDialog(IMessageProvider messageProvider,
+            List<T> data, AbstractAsyncCallback<Void> callback, boolean withRadio)
+    {
+        this(messageProvider, data, callback, withRadio, true);
     }
 
-    // without radio
+    // without radio & permanently
     public AbstractDataListDeletionConfirmationDialog(IMessageProvider messageProvider,
             List<T> data, AbstractAsyncCallback<Void> callback)
     {
-        this(messageProvider, data, callback, false);
+        this(messageProvider, data, callback, false, false);
     }
 
     @Override
@@ -78,6 +99,10 @@ public abstract class AbstractDataListDeletionConfirmationDialog<T> extends
         reason = new ReasonField(messageProvider, true);
         reason.focus();
         reason.addKeyListener(keyListener);
+        if (withInvalidateOption)
+        {
+            formPanel.add(permanentCheckBoxOrNull = createDeletePermanentlyCheckBox());
+        }
         if (withRadio)
         {
             formPanel.add(createRadio());
@@ -98,7 +123,7 @@ public abstract class AbstractDataListDeletionConfirmationDialog<T> extends
                     (isOnlySelected() ? data.size() + SELECTED : ALL_EMPHASIZED) + getEntityName();
         }
         return messageProvider.getMessage(Dict.DELETE_CONFIRMATION_MESSAGE_WITH_REASON,
-                deletedObjects);
+                isPermanentDeletion() ? PERMANENTLY_EMPHASIZED : TEMPORARILY, deletedObjects);
     }
 
     protected abstract String getEntityName();
@@ -120,18 +145,38 @@ public abstract class AbstractDataListDeletionConfirmationDialog<T> extends
         return null;
     }
 
+    private CheckBoxField createDeletePermanentlyCheckBox()
+    {
+        CheckBoxField result = new CheckBoxField(messageProvider.getMessage(Dict.PERMANENT), false);
+        result.setValue(true);
+        result.addListener(Events.Change, new Listener<FieldEvent>()
+            {
+                public void handleEvent(FieldEvent fe)
+                {
+                    refreshMessage();
+                }
+            });
+        return result;
+    }
+
     protected final boolean isOnlySelected()
     {
         return WidgetUtils.isSelected(onlySelectedRadioOrNull);
     }
 
+    protected final boolean isPermanentDeletion()
+    {
+        return permanentCheckBoxOrNull == null || permanentCheckBoxOrNull.getValue();
+    }
+
     /**
      * Returns deletion callback and shows a progress bar that will be hidden when the callback is
      * finished.
      */
     private AsyncCallback<Void> getCallbackWithProgressBar()
     {
-        return AsyncCallbackWithProgressBar.decorate(callback,
-                messageProvider.getMessage(Dict.DELETE_PROGRESS_MESSAGE, getEntityName()));
+        return AsyncCallbackWithProgressBar.decorate(callback, messageProvider.getMessage(
+                isPermanentDeletion() ? Dict.DELETE_PROGRESS_MESSAGE
+                        : Dict.INVALIDATE_PROGRESS_MESSAGE, getEntityName()));
     }
 }
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/server/CommonClientService.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/server/CommonClientService.java
index 6d4a4f88713ca67849355155bcd272074129aaad..e392b983a7be8388b79eece966aee464696b66ea 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/server/CommonClientService.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/client/web/server/CommonClientService.java
@@ -115,6 +115,7 @@ import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DataSetTypePropertyType
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DataStoreServiceKind;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DataType;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DatastoreServiceDescription;
+import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DeletionType;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DetailedSearchCriteria;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DynamicPropertyEvaluationInfo;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.EntityKind;
@@ -1577,26 +1578,27 @@ public final class CommonClientService extends AbstractClientService implements
         }
     }
 
-    public void deleteSamples(List<TechId> sampleIds, String reason)
+    public void deleteSamples(List<TechId> sampleIds, String reason, DeletionType deletionType)
             throws ch.systemsx.cisd.openbis.generic.client.web.client.exception.UserFailureException
     {
         try
         {
             final String sessionToken = getSessionToken();
-            commonServer.deleteSamples(sessionToken, sampleIds, reason);
+            commonServer.deleteSamples(sessionToken, sampleIds, reason, deletionType);
         } catch (final UserFailureException e)
         {
             throw UserFailureExceptionTranslator.translate(e);
         }
     }
 
-    public void deleteSample(TechId sampleId, String reason)
+    public void deleteSample(TechId sampleId, String reason, DeletionType deletionType)
             throws ch.systemsx.cisd.openbis.generic.client.web.client.exception.UserFailureException
     {
         try
         {
             final String sessionToken = getSessionToken();
-            commonServer.deleteSamples(sessionToken, Collections.singletonList(sampleId), reason);
+            commonServer.deleteSamples(sessionToken, Collections.singletonList(sampleId), reason,
+                    deletionType);
         } catch (final UserFailureException e)
         {
             throw UserFailureExceptionTranslator.translate(e);
@@ -1604,14 +1606,14 @@ public final class CommonClientService extends AbstractClientService implements
     }
 
     public void deleteSamples(DisplayedOrSelectedIdHolderCriteria<? extends IIdHolder> criteria,
-            String reason)
+            String reason, DeletionType deletionType)
             throws ch.systemsx.cisd.openbis.generic.client.web.client.exception.UserFailureException
     {
         try
         {
             final String sessionToken = getSessionToken();
             List<TechId> sampleIds = extractTechIds(criteria);
-            commonServer.deleteSamples(sessionToken, sampleIds, reason);
+            commonServer.deleteSamples(sessionToken, sampleIds, reason, deletionType);
         } catch (final UserFailureException e)
         {
             throw UserFailureExceptionTranslator.translate(e);
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/CommonServer.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/CommonServer.java
index 17eafa058b1b0f6c5d6f05603e29a8bada06b411..b58ea493799aff4b9701789e89a1ecd691ff933c 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/CommonServer.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/CommonServer.java
@@ -102,6 +102,7 @@ import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DataStoreServiceKind;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DataType;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DatastoreServiceDescription;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DeletedDataSet;
+import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DeletionType;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DetailedSearchCriteria;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DynamicPropertyEvaluationInfo;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.EntityKind;
@@ -1166,13 +1167,22 @@ public final class CommonServer extends AbstractCommonServer<ICommonServerForInt
         }
     }
 
-    public void deleteSamples(String sessionToken, List<TechId> sampleIds, String reason)
+    public void deleteSamples(String sessionToken, List<TechId> sampleIds, String reason,
+            DeletionType deletionType)
     {
         Session session = getSession(sessionToken);
         try
         {
             ISampleTable sampleTableBO = businessObjectFactory.createSampleTable(session);
-            sampleTableBO.deleteByTechIds(sampleIds, reason);
+            switch (deletionType)
+            {
+                case PERMANENT:
+                    sampleTableBO.deleteByTechIds(sampleIds, reason);
+                    break;
+                case INVALIDATION:
+                    sampleTableBO.invalidateByTechIds(sampleIds, reason);
+                    break;
+            }
         } catch (final DataAccessException ex)
         {
             throw createUserFailureException(ex);
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/CommonServerLogger.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/CommonServerLogger.java
index 2a913397bce309b77d3713fc9f49de3316da1130..bc09b0c62b188b472b3efb8a603b415781a1a41f 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/CommonServerLogger.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/CommonServerLogger.java
@@ -41,6 +41,7 @@ import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DataSetUpdateResult;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DataStoreServiceKind;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DataType;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DatastoreServiceDescription;
+import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DeletionType;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DetailedSearchCriteria;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DetailedSearchSubCriteria;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DynamicPropertyEvaluationInfo;
@@ -581,10 +582,11 @@ final class CommonServerLogger extends AbstractServerLogger implements ICommonSe
                 abbreviate(dataSetCodes), reason);
     }
 
-    public void deleteSamples(String sessionToken, List<TechId> sampleIds, String reason)
+    public void deleteSamples(String sessionToken, List<TechId> sampleIds, String reason,
+            DeletionType deletionType)
     {
-        logTracking(sessionToken, "delete_samples", "IDS(%s) REASON(%s)", abbreviate(sampleIds),
-                reason);
+        logTracking(sessionToken, "delete_samples", "TYPE(%s) IDS(%s) REASON(%s)", deletionType,
+                abbreviate(sampleIds), reason);
     }
 
     public void deleteExperiments(String sessionToken, List<TechId> experimentIds, String reason)
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/business/bo/ISampleTable.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/business/bo/ISampleTable.java
index edf03ef6e9e455e23b74b9926f9cd96cd69e3d81..b2aeda9c6da3ff6c50fe31698f9eca4eebbe0945 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/business/bo/ISampleTable.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/business/bo/ISampleTable.java
@@ -71,4 +71,13 @@ public interface ISampleTable
      */
     public void deleteByTechIds(List<TechId> sampleIds, String reason) throws UserFailureException;
 
+    /**
+     * Invalidates samples for specified reason.
+     * 
+     * @param sampleIds sample technical identifiers
+     * @throws UserFailureException if one of the samples can not be invalidated.
+     */
+    public void invalidateByTechIds(List<TechId> sampleIds, String reason)
+            throws UserFailureException;
+
 }
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/business/bo/SampleTable.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/business/bo/SampleTable.java
index 42c245bbe3f9647ba4caa3f46ccf581a380798ea..b78e338a97c005ddb34e5fcd7746b8b3ca1eca09 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/business/bo/SampleTable.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/business/bo/SampleTable.java
@@ -340,4 +340,18 @@ public final class SampleTable extends AbstractSampleBusinessObject implements I
         }
     }
 
+    public void invalidateByTechIds(List<TechId> sampleIds, String reason)
+            throws UserFailureException
+    {
+        try
+        {
+            getSessionFactory().getCurrentSession().flush();
+            getSessionFactory().getCurrentSession().clear();
+            getSampleDAO().invalidate(sampleIds, session.tryGetPerson(), reason);
+        } catch (final DataAccessException ex)
+        {
+            throwException(ex, "Sample", EntityKind.SAMPLE);
+        }
+    }
+
 }
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/dataaccess/db/AbstractGenericEntityDAO.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/dataaccess/db/AbstractGenericEntityDAO.java
index 9bffc9c7566b06e7eabd78799d0004237f10f20e..3063b7767a88e504cac58274299cdbaa9aca7935 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/dataaccess/db/AbstractGenericEntityDAO.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/dataaccess/db/AbstractGenericEntityDAO.java
@@ -72,7 +72,7 @@ public abstract class AbstractGenericEntityDAO<T extends IIdHolder> extends Abst
                     + techId.getId() + " does not exist. Maybe someone has just deleted it.");
         } else
         {
-            result = getEntity(getHibernateTemplate().get(getEntityClass(), techId.getId()));
+            result = getEntity(entity);
         }
         if (operationLog.isDebugEnabled())
         {
@@ -82,6 +82,12 @@ public abstract class AbstractGenericEntityDAO<T extends IIdHolder> extends Abst
         return result;
     }
 
+    public final T loadByTechId(final TechId techId) throws DataAccessException
+    {
+        assert techId != null : "Technical identifier unspecified.";
+        return getEntity(getHibernateTemplate().load(getEntityClass(), techId.getId()));
+    }
+
     private String getEntityDescription()
     {
         String nameWithoutPE = getEntityClass().getSimpleName().replace("PE", "");
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/dataaccess/db/SampleDAO.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/dataaccess/db/SampleDAO.java
index fe9291cfe13b67b218ce6c41ca635d2d28c46385..9dcd63bf55eeece69e463d8fee74e3ce22811fce 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/dataaccess/db/SampleDAO.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/dataaccess/db/SampleDAO.java
@@ -45,6 +45,7 @@ import ch.systemsx.cisd.openbis.generic.shared.basic.TechId;
 import ch.systemsx.cisd.openbis.generic.shared.dto.DatabaseInstancePE;
 import ch.systemsx.cisd.openbis.generic.shared.dto.EventPE.EntityType;
 import ch.systemsx.cisd.openbis.generic.shared.dto.EventType;
+import ch.systemsx.cisd.openbis.generic.shared.dto.InvalidationPE;
 import ch.systemsx.cisd.openbis.generic.shared.dto.PersonPE;
 import ch.systemsx.cisd.openbis.generic.shared.dto.SamplePE;
 import ch.systemsx.cisd.openbis.generic.shared.dto.SamplePropertyPE;
@@ -439,6 +440,26 @@ public class SampleDAO extends AbstractGenericEntityWithPropertiesDAO<SamplePE>
         scheduleRemoveFromFullTextIndex(ids);
     }
 
+    public void invalidate(final List<TechId> sampleIds, final PersonPE registrator,
+            final String reason) throws DataAccessException
+    {
+        // TODO 2011-06-16, Piotr Buczek: move when cascade invalidation is implemented
+        InvalidationPE invalidation = new InvalidationPE();
+        invalidation.setReason(reason);
+        invalidation.setRegistrator(registrator);
+        getHibernateTemplate().save(invalidation);
+
+        // TODO 2011-06-16, Piotr Buczek: could be done faster with bulk update
+        for (TechId sampleId : sampleIds)
+        {
+            SamplePE sample = loadByTechId(sampleId);
+            sample.setInvalidation(invalidation);
+            getHibernateTemplate().update(sample);
+        }
+
+        getHibernateTemplate().flush();
+    }
+
     @SuppressWarnings("unchecked")
     public Set<TechId> listParents(final Collection<TechId> children, final TechId relationship)
     {
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/shared/ICommonServer.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/shared/ICommonServer.java
index 066f0ce4c4814c0ef30b61d731929765f91d16a3..520b457b666495697622df8b2d0792588c4c2ab7 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/shared/ICommonServer.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/shared/ICommonServer.java
@@ -68,6 +68,7 @@ import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DataStoreServiceKind;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DataType;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DatabaseModificationKind.ObjectKind;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DatastoreServiceDescription;
+import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DeletionType;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DetailedSearchCriteria;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DynamicPropertyEvaluationInfo;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.EntityKind;
@@ -756,7 +757,7 @@ public interface ICommonServer extends IServer
     public void deleteSamples(
             String sessionToken,
             @AuthorizationGuard(guardClass = SampleTechIdCollectionPredicate.class) List<TechId> sampleIds,
-            String reason);
+            String reason, DeletionType type);
 
     /**
      * Deletes specified experiments.
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/shared/basic/IInvalidationProvider.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/shared/basic/IInvalidationProvider.java
index 06c013e36f10862ed3ba28e35b33e4144c15cb85..68d815bcd682e32b593ea4e68fc39b088e39d62a 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/shared/basic/IInvalidationProvider.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/shared/basic/IInvalidationProvider.java
@@ -19,12 +19,9 @@ package ch.systemsx.cisd.openbis.generic.shared.basic;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.Invalidation;
 
 /**
- * 
- *
- * @author     Franz-Josef Elmer
+ * @author Franz-Josef Elmer
  */
 public interface IInvalidationProvider
 {
     public Invalidation getInvalidation();
-
 }
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/shared/basic/dto/DeletionType.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/shared/basic/dto/DeletionType.java
new file mode 100644
index 0000000000000000000000000000000000000000..39c93cbbfc9c108053e2ce11a54e0bfdc9576fa8
--- /dev/null
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/shared/basic/dto/DeletionType.java
@@ -0,0 +1,29 @@
+/*
+ * Copyright 2007 ETH Zuerich, CISD
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+package ch.systemsx.cisd.openbis.generic.shared.basic.dto;
+
+import ch.systemsx.cisd.openbis.generic.shared.basic.ISerializable;
+
+/**
+ * Types of deletion operations.
+ * 
+ * @author Piotr Buczek
+ */
+public enum DeletionType implements ISerializable
+{
+    PERMANENT, INVALIDATION
+}
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/shared/dto/InvalidationPE.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/shared/dto/InvalidationPE.java
index 3648115ab563569054e4dc37c2729db24d848f96..8a25039fb907b043770d08bb6a17d40055e8b2d3 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/shared/dto/InvalidationPE.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/shared/dto/InvalidationPE.java
@@ -38,7 +38,7 @@ import ch.systemsx.cisd.openbis.generic.shared.basic.IIdHolder;
 /**
  * Class representing invalidation.
  * 
- * @author     Franz-Josef Elmer
+ * @author Franz-Josef Elmer
  */
 @Entity
 @Table(name = TableNames.INVALIDATION_TABLE)
@@ -47,7 +47,7 @@ public class InvalidationPE extends HibernateAbstractRegistrationHolder implemen
 {
     private static final long serialVersionUID = IServer.VERSION;
 
-    private transient Long id;
+    private Long id;
 
     private String reason;
 
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/plugin/generic/client/web/client/application/sample/GenericSampleViewer.java b/openbis/source/java/ch/systemsx/cisd/openbis/plugin/generic/client/web/client/application/sample/GenericSampleViewer.java
index 7f2ea5c3a0391a8cf17ea70b791c1f3d8be6523b..37a3b196ca1066e83675c171c552c7817ff8e211 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/plugin/generic/client/web/client/application/sample/GenericSampleViewer.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/plugin/generic/client/web/client/application/sample/GenericSampleViewer.java
@@ -265,7 +265,6 @@ abstract public class GenericSampleViewer extends AbstractViewerWithVerticalSpli
         final Map<String, Object> properties = new LinkedHashMap<String, Object>();
         final Sample sample = sampleGeneration.getParent();
         final SampleType sampleType = sample.getSampleType();
-        final Invalidation invalidation = sample.getInvalidation();
         final Sample[] generated = sampleGeneration.getDerived();
         properties.put(viewContext.getMessage(Dict.SAMPLE_PROPERTIES_PANEL_SAMPLE_IDENTIFIER),
                 sample.getIdentifier());
@@ -275,6 +274,7 @@ abstract public class GenericSampleViewer extends AbstractViewerWithVerticalSpli
         properties.put(viewContext.getMessage(Dict.REGISTRATOR), sample.getRegistrator());
         properties
                 .put(viewContext.getMessage(Dict.REGISTRATION_DATE), sample.getRegistrationDate());
+        final Invalidation invalidation = sample.getInvalidation();
         if (invalidation != null)
         {
             properties.put(viewContext.getMessage(Dict.INVALIDATION), invalidation);
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/public/common-dictionary.js b/openbis/source/java/ch/systemsx/cisd/openbis/public/common-dictionary.js
index b79e7b58f5710bb69e18b183730ff45161d7fc6b..bd3afded33a3c8f10724e2579a5a2f90be8033b4 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/public/common-dictionary.js
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/public/common-dictionary.js
@@ -41,9 +41,6 @@ var common = {
   entity_operations: "Entity:",
   url: "URL",
   is_official: "Approved?",
-  reason: "Reason",
-  delete_confirmation_message_with_reason: "You are deleting {0}(s).<br><br>Please enter a reason or cancel deletion.",
-  delete_progress_message: "Deleting {0}(s)...",
   add_attachment: "Add attachment...",
   data_view: "Data View",
   container_type: "Container",
@@ -59,6 +56,21 @@ var common = {
   explore_label: "Explore:",
   add_unofficial_vocabulary_term_dialog_title: "Add Ad Hoc Term",
   breadcrumbs_separator: "»",
+	 
+  //
+  // Deletion
+  // 
+  
+  invalidate: "Invalidate",
+  invalidation: "Invalidation",
+  invalidation_template: "Invalidated by: {0}<br>date: {1}<br>reason: {2}",
+  permanent: "Permanent",
+  reason: "Reason",
+  delete_confirmation_title: "Confirm Deletion",
+  delete_confirmation_message: "Are you sure you want to delete [{0}]?",
+  delete_confirmation_message_with_reason: "You are {0} deleting {1}(s).<br><br>Please enter a reason or cancel deletion.",
+  delete_progress_message: "Deleting {0}(s)...",
+  delete_progress_message: "Invalidating {0}(s)...",
 	 
   //
   // Table Modifications
@@ -203,8 +215,6 @@ var common = {
   part_of: "Container",
   generatedfromparent: "Parents",
   containerparent: "Container",
-  invalidation: "Invalidation",
-  invalidation_template: "Invalidated by: {0}<br>Invalidation Date: {1}<br>Invalidation Reason: {2}",
   
   //
   // Experiment Browser
@@ -244,8 +254,6 @@ var common = {
   edit_type_button: "Edit",
   add_type_title_template: "Add a new {0} Type",
   edit_type_title_template: "Edit {0} Type {1}",
-  delete_confirmation_title: "Confirm Deletion",
-  delete_confirmation_message: "Are you sure you want to delete [{0}]?",
   
   //
   // Sample Type Browser
diff --git a/openbis/sourceTest/java/ch/systemsx/cisd/openbis/systemtest/ExperimentBrowsingTest.java b/openbis/sourceTest/java/ch/systemsx/cisd/openbis/systemtest/ExperimentBrowsingTest.java
index 95b02d2b6e4524bd17a96bf637a104c6438bfc44..debf1c9353e1e9012ba74fc16958c96e66726a20 100644
--- a/openbis/sourceTest/java/ch/systemsx/cisd/openbis/systemtest/ExperimentBrowsingTest.java
+++ b/openbis/sourceTest/java/ch/systemsx/cisd/openbis/systemtest/ExperimentBrowsingTest.java
@@ -16,7 +16,6 @@
 
 package ch.systemsx.cisd.openbis.systemtest;
 
-
 import static org.testng.AssertJUnit.assertEquals;
 
 import org.testng.annotations.Test;
@@ -31,8 +30,6 @@ import ch.systemsx.cisd.openbis.generic.shared.basic.dto.Project;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.Space;
 
 /**
- * 
- *
  * @author Franz-Josef Elmer
  */
 @Test(groups = "system test")
@@ -61,7 +58,7 @@ public class ExperimentBrowsingTest extends SystemTestCase
         assertEquals(5, resultSet.getResultSet().getTotalLength());
         assertEquals(5, resultSet.getResultSet().getList().size());
     }
-    
+
     @Test
     public void testListExperiments()
     {
@@ -85,7 +82,7 @@ public class ExperimentBrowsingTest extends SystemTestCase
         assertEquals(3, resultSet.getResultSet().getTotalLength());
         assertEquals(3, resultSet.getResultSet().getList().size());
     }
-    
+
     @Test
     public void testListExperimentsPartially()
     {
@@ -101,13 +98,13 @@ public class ExperimentBrowsingTest extends SystemTestCase
         project.setCode("NEMO");
         criteria.setProject(project);
         criteria.setLimit(2);
-        criteria.setCacheConfig(ResultSetFetchConfig.<String>createComputeAndCache());
+        criteria.setCacheConfig(ResultSetFetchConfig.<String> createComputeAndCache());
         TypedTableResultSet<Experiment> resultSet = commonClientService.listExperiments(criteria);
         String key = resultSet.getResultSet().getResultSetKey();
         assertEquals(true, resultSet.getResultSet().isPartial());
         assertEquals(2, resultSet.getResultSet().getTotalLength());
         assertEquals(2, resultSet.getResultSet().getList().size());
-        
+
         criteria.setCacheConfig(ResultSetFetchConfig.createFetchFromCacheAndRecompute(key));
         resultSet = commonClientService.listExperiments(criteria);
         assertEquals(key, resultSet.getResultSet().getResultSetKey());
diff --git a/openbis/sourceTest/java/ch/systemsx/cisd/openbis/systemtest/plugin/generic/DynamicPropertiesEvaluationTest.java b/openbis/sourceTest/java/ch/systemsx/cisd/openbis/systemtest/plugin/generic/DynamicPropertiesEvaluationTest.java
index 0e8cf69f580f0c529b8cc6eda41f3d572c0cd145..ca2a5e7da72a861bb84159f8d8ec9448c12d9762 100644
--- a/openbis/sourceTest/java/ch/systemsx/cisd/openbis/systemtest/plugin/generic/DynamicPropertiesEvaluationTest.java
+++ b/openbis/sourceTest/java/ch/systemsx/cisd/openbis/systemtest/plugin/generic/DynamicPropertiesEvaluationTest.java
@@ -36,6 +36,7 @@ import ch.systemsx.cisd.openbis.generic.client.web.client.dto.ResultSetWithEntit
 import ch.systemsx.cisd.openbis.generic.client.web.client.dto.SampleUpdates;
 import ch.systemsx.cisd.openbis.generic.shared.basic.GridRowModel;
 import ch.systemsx.cisd.openbis.generic.shared.basic.TechId;
+import ch.systemsx.cisd.openbis.generic.shared.basic.dto.DeletionType;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.EntityKind;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.IEntityProperty;
 import ch.systemsx.cisd.openbis.generic.shared.basic.dto.ListSampleCriteria;
@@ -362,7 +363,8 @@ public class DynamicPropertiesEvaluationTest extends GenericSystemTestCase
         commonClientService.unassignPropertyType(EntityKind.SAMPLE, DESCRIPTION, CELL_PLATE);
         if (createdSampleId != null)
         {
-            commonClientService.deleteSample(createdSampleId, "test cleanup");
+            commonClientService.deleteSample(createdSampleId, "test cleanup",
+                    DeletionType.PERMANENT);
         }
     }
 }
diff --git a/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/dataaccess/ISampleDAO.java b/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/dataaccess/ISampleDAO.java
index c6eeea87ef205d2abd136cf3f243d2519a9048ef..ca4d43c8a9e2d9bf4e8a52f0b5205d1e029a9886 100644
--- a/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/dataaccess/ISampleDAO.java
+++ b/openbis/source/java/ch/systemsx/cisd/openbis/generic/server/dataaccess/ISampleDAO.java
@@ -117,8 +117,14 @@ public interface ISampleDAO extends IGenericDAO<SamplePE>
     List<SamplePE> listByPermID(Set<String> values);
 
     /**
      * Delete samples with given by specified registrator with specified reason.
      */
     void delete(List<TechId> sampleIds, PersonPE registrator, String reason)
             throws DataAccessException;
+
+    /**
+     * Invalidate samples with given ids by specified registrator with specified reason.
+     */
+    void invalidate(List<TechId> sampleIds, PersonPE registrator, String reason)
+            throws DataAccessException;
 }
@@ -117,8 +117,14 @@ public interface ISampleDAO extends IGenericDAO<SamplePE>
 
     /**
-     * Delete samples with given by specified registrator with specified reason.
+     * Delete samples with given ids by specified registrator with specified reason.
      */
     void delete(List<TechId> sampleIds, PersonPE registrator, String reason)